@@ -725,19 +725,20 @@ class RealServer(HttpClient, KempBaseObjectModel):
 
     def _get_base_parameters(self):
         """Returns the bare minimum VS parameters. IP, port and protocol"""
-        if self.rsindex is None:
-            return {
-                "vs": self.vs,
-                "port": self.port,
-                "prot": self.prot,
-                "rs": self.rs,
-                "rsport": self.rsport,
-            }
-        else:
-            return {
-                "vs": self.vsindex,
-                "rs": "!{}".format(self.rsindex),
-            }
+        # Comment out this code until vsindex is correct on a showrs call.
+        #if self.rsindex is None:
+        return {
+            "vs": self.vs,
+            "port": self.port,
+            "prot": self.prot,
+            "rs": self.rs,
+            "rsport": self.rsport,
+        }
+        #else:
+        #    return {
+        #        "vs": self.vsindex,
+        #        "rs": "!{}".format(self.rsindex),
+        #    }
 
     def save(self, update=False):
         if not update:
